@@ -11,18 +11,6 @@ from converter.advanced_ddl.advanced_ddl_creator import AdvancedDDLCreator
 
 warnings.filterwarnings("ignore")
 
-logging.basicConfig(
-    stream=sys.stdout,
-    level=logging.INFO,
-    format="%(asctime)s  %(name)s  %(levelname)s: %(message)s",
-)
-logging.basicConfig(
-    stream=sys.stderr,
-    level=logging.ERROR,
-    format="%(asctime)s  %(name)s  %(levelname)s: %(message)s",
-)
-logging.captureWarnings(True)
-
 
 def save_ddl_to_file(sql, table_name, ddl_dir):
     """
@@ -32,20 +20,20 @@ def save_ddl_to_file(sql, table_name, ddl_dir):
     :param ddl_dir:
     :return:
     """
-    f = open(ddl_dir + "/" + table_name + ".sql", "w",)
+    f = open(ddl_dir + "/" + table_name + ".sql", "w", )
     f.write(sql)
     f.close()
 
 
 class FieldsConverter:
     def __init__(
-        self,
-        sql_credentials,
-        from_db,
-        to_db,
-        debug=True,
-        tables=None,
-        advanced_features=None,
+            self,
+            sql_credentials,
+            from_db,
+            to_db,
+            debug=True,
+            tables=None,
+            advanced_features=None,
     ):
         """
         Class ddl-converter from one database to another
@@ -56,6 +44,12 @@ class FieldsConverter:
         :param tables: converter only for list of tables. Will process more rapidly
         :param advanced_features: 0 - get sizes of text, 1 - to primary key constraint
         """
+        log_format = "%(asctime)-15s %(name)s:%(levelname)s: %(message)s"
+        logging.basicConfig(format=log_format, stream=sys.stdout, level=logging.INFO)
+        logging.basicConfig(format=log_format, stream=sys.stderr, level=logging.ERROR)
+        logging.captureWarnings(True)
+        self.logger = logging.getLogger(__class__.__name__)
+
         self.advanced_features = advanced_features or []
         self.tables = tables or []
         self.from_db = from_db
@@ -69,10 +63,6 @@ class FieldsConverter:
             sql_credentials, to_db, debug, tables, table_checker=False
         )
 
-    def log(self, text):
-        if self.debug:
-            logging.info(self.__str__ + ": " + text)
-
     def __check_converter(self):
         if self.key not in types_converter_dict:
             raise NotImplementedError(
@@ -90,7 +80,7 @@ class FieldsConverter:
         return "FieldsConverter_{}_{}".format(self.from_db, self.to_db)
 
     def __get_fields_definition(
-        self, table_name, field_name, field_type, attributes={}
+            self, table_name, field_name, field_type, attributes={}
     ):
         """
         Get field definition result
@@ -101,16 +91,16 @@ class FieldsConverter:
         """
         if "text_sizes" in attributes and field_name in attributes["text_sizes"]:
             if (
-                field_type == "long varchar"
-                and attributes["text_sizes"][field_name] < 65000
+                    field_type == "long varchar"
+                    and attributes["text_sizes"][field_name] < 65000
             ):
                 field_type = "varchar"
             text_size = "(" + str(attributes["text_sizes"][field_name]) + ")"
         else:
             text_size = ""
         if (
-            "constrained_columns" in attributes
-            and field_name in attributes["constrained_columns"]
+                "constrained_columns" in attributes
+                and field_name in attributes["constrained_columns"]
         ):
             constrained = " " + base_converter_params[self.to_db][
                 "constrained_columns_str"
@@ -161,7 +151,7 @@ class FieldsConverter:
         """
         attributes = {}
         if len(self.advanced_features) > 0:
-            self.log("advanced ddl creator. get additional attrs")
+            self.logger.info("advanced ddl creator. get additional attributes")
             adv_ddl = AdvancedDDLCreator(
                 fields_converter=self, advanced_features=self.advanced_features
             )
@@ -196,21 +186,23 @@ class FieldsConverter:
         return self.generate_create(fields_new, table_name)
 
     def drop_list_of_tables(self, tables):
-        """drop every fkn table in list"""
+        """drop every fkn table in a list"""
         for table in tables:
             sql = "drop table {schema}.{table} cascade ".format(
                 schema=self.db_worker_to.schema, table=table
             )
             self.db_worker_to.conn.execute(sql)
 
-    def create_list_of_tables(self, tables, to_create=True, dir_ddl=None):
+    def create_list_of_tables(self, tables, to_create=True, dir_ddl=None, suffix=None):
         result_list = []
         for table in tables:
             sql = self.create_ddl(table_name=table)
+            if suffix:
+                sql = sql.replace(");", ") " + suffix + ";")
             result_list.append(sql)
             if to_create:
                 self.db_worker_to.conn.execute(sql)
-                logging.info("creating table {} is successfull".format(table))
+                self.logger.info("creating table {} is successful".format(table))
             if dir_ddl is not None:
                 save_ddl_to_file(sql=sql, table_name=table, ddl_dir=dir_ddl)
         return result_list
